==> as2-lib-4.6.0-sources.jar: com/helger/as2lib/crypto/IMICMatchingHandler.java <==
/**
 * The FreeBSD Copyright
 * Copyright 1994-2008 The FreeBSD Project. All rights reserved.
 * Copyright (C) 2013-2020 Philip Helger philip[at]helger[dot]com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE FREEBSD PROJECT ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FREEBSD PROJECT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of the FreeBSD Project.
 */
package com.helger.as2lib.crypto;

import java.io.Serializable;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import com.helger.as2lib.exception.AS2Exception;
import com.helger.as2lib.message.IMessage;

/**
 * A special handler if MIC is not matched.
 *
 * @author Philip Helger
 * @since 4.4.0
 */
public interface IMICMatchingHandler extends Serializable
{
  /**
   * Invoked upon MIC match
   *
   * @param aMsg
   *        The message it is all about. Never null
   * @param sMIC
   *        The MIC calculated and received. May not be <code>null</code>.
   * @throws AS2Exception
   *         In case of error
   */
  void onMICMatch (@Nonnull IMessage aMsg, @Nonnull String sMIC) throws AS2Exception;

  /**
   * Invoked upon MIC mismatch
   *
   * @param aMsg
   *        The message it is all about. Never null
   * @param sOriginalMIC
   *        The MIC calculated here. May be <code>null</code>.
   * @param sReceivedMIC
   *        The MIC received from the other side. May be <code>null</code>.
   * @throws AS2Exception
   *         In case of error
   */
  void onMICMismatch (@Nonnull IMessage aMsg,
                      @Nullable String sOriginalMIC,
                      @Nullable String sReceivedMIC) throws AS2Exception;
}

==> as2-lib-4.11.0-sources.jar: com/helger/as2lib/crypto/IMICMatchingHandler.java <==
/*
 * The FreeBSD Copyright
 * Copyright 1994-2008 The FreeBSD Project. All rights reserved.
 * Copyright (C) 2013-2022 Philip Helger philip[at]helger[dot]com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE FREEBSD PROJECT ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FREEBSD PROJECT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of the FreeBSD Project.
 */
package com.helger.as2lib.crypto;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import com.helger.as2lib.exception.AS2Exception;
import com.helger.as2lib.message.IMessage;

/**
 * A special handler if MIC is not matched.
 *
 * @author Philip Helger
 * @since 4.4.0
 */
public interface IMICMatchingHandler
{
  /**
   * Invoked upon MIC match
   *
   * @param aMsg
   *        The message it is all about. Never null
   * @param sMIC
   *        The MIC calculated and received. May not be <code>null</code>.
   * @throws AS2Exception
   *         In case of error
   */
  void onMICMatch (@Nonnull IMessage aMsg, @Nonnull String sMIC) throws AS2Exception;

  /**
   * Invoked upon MIC mismatch
   *
   * @param aMsg
   *        The message it is all about. Never null
   * @param sOriginalMIC
   *        The MIC calculated here. May be <code>null</code>.
   * @param sReceivedMIC
   *        The MIC received from the other side. May be <code>null</code>.
   * @throws AS2Exception
   *         In case of error
   */
  void onMICMismatch (@Nonnull IMessage aMsg, @Nullable String sOriginalMIC, @Nullable String sReceivedMIC) throws AS2Exception;
}
